// *************************************************************************************
// SCICHART  Copyright ABT Software Services Ltd. 2011-2012. All rights reserved.
//  
// Web: http://www.scichart.com
// Support: info@abtsoftware.co.uk
//  
// Timer.cs is part of SciChart Examples, a High Performance WPF & Silverlight Chart. 
// For full terms and conditions of the SciChart license, see http://www.scichart.com/scichart-eula/
//  
// SciChart Examples source code is provided free of charge on an "As-Is" basis to support
// and provide examples of how to use the SciChart component. You bear the risk of using it. 
// The authors give no express warranties, guarantees or conditions. You may have additional 
// consumer rights under your local laws which this license cannot change. To the extent 
// permitted under your local laws, the contributors exclude the implied warranties of 
// merchantability, fitness for a particular purpose and non-infringement. 
// *************************************************************************************
namespace System.Timers
{
    /// <summary>
    /// Drop in Silverlight compatible replacement for the System.Timers.Timer
    /// Doesn't do synchronisation
    /// </summary>
    public class Timer
    {
        private readonly uint _interval;
        private System.Threading.Timer _internalTimer;
        private bool _isEnabled;
        private const uint MaxTime = (uint)0xFFFFFFFD;

        public event EventHandler<EventArgs> Elapsed;

        public Timer(uint interval)
        {
            _interval = interval;
        }

        public Timer(double interval)
        {
            _interval = (uint)interval;
        }

        public bool AutoReset { get; set; }

        public bool Enabled
        {
            get { return _isEnabled; }
            set
            {
                _isEnabled = value;

                if (_isEnabled)
                {
                    Start();
                }
                else
                {
                    Stop();
                }
            }
        }

        public void Start()
        {
            _isEnabled = true;

            Stop();
            _internalTimer = CreateTimer();            
        }        

        public void Stop()
        {
            if (_internalTimer != null)
            {
                _isEnabled = false;

                _internalTimer.Change(MaxTime, MaxTime);
                _internalTimer.Dispose();
                _internalTimer = null;
            }
        }

        private Threading.Timer CreateTimer()
        {
            var timer = new System.Threading.Timer(InternalTick);
            timer.Change(_interval, AutoReset ? _interval : MaxTime);
            return timer;
        }

        private void InternalTick(object state)
        {
            var handler = Elapsed;
            if (handler != null)
            {
                handler(this, EventArgs.Empty);
            }
        }
    }
}