﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Interactivity;
using Abt.Controls.SciChart.Example.Helpers;

namespace Abt.Controls.SciChart.Example.Behaviors
{
    public class BindableSelectedItemBehavior : Behavior<TreeView>
    {
        public static DependencyProperty BindableSelectedItemProperty =
            DependencyProperty.Register("BindableSelectedItem",
                                        typeof (Example),
                                        typeof (BindableSelectedItemBehavior),
                                        new PropertyMetadata(OnBindableSelectedItemChanged));

        public Example BindableSelectedItem
        {
            get { return (Example) GetValue(BindableSelectedItemProperty); }
            set { SetValue(BindableSelectedItemProperty, value); }
        }

        protected override void OnAttached()
        {
            base.OnAttached();

            AssociatedObject.SelectedItemChanged += OnTreeViewSelectedItemChanged;
        }

        protected override void OnDetaching()
        {
            base.OnDetaching();

            AssociatedObject.SelectedItemChanged -= OnTreeViewSelectedItemChanged;
        }

        private static void OnBindableSelectedItemChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var behavior = (BindableSelectedItemBehavior) d;
            behavior.AssociatedObject.Select(behavior.BindableSelectedItem);
        }

        private void OnTreeViewSelectedItemChanged(object sender, RoutedPropertyChangedEventArgs<object> e)
        {
            var example = AssociatedObject.SelectedItem as Example;

            if (example != null && !example.Equals(BindableSelectedItem))
            {
                example.SelectCommand.Execute(example);
            }
        }
    }
}
