﻿using System.Windows;

namespace Abt.Controls.SciChart.Example.Common
{
    public enum FrameworkVisibility
    {
        All,
        Wpf, 
        Silverlight
    }

    /// <summary>
    /// Used to show or hide UIElements based on framework (WPF, Silverlight)
    /// </summary>
    public class FrameworkVisibilityManager : FrameworkElement
    {
        public static readonly DependencyProperty VisibleInProperty =
            DependencyProperty.RegisterAttached("VisibleIn", typeof(FrameworkVisibility), typeof(FrameworkVisibilityManager), new PropertyMetadata(FrameworkVisibility.All, OnVisibleInPropertyChanged));        

        public static void SetVisibleIn(DependencyObject element, FrameworkVisibility visibleIn)
        {
            element.SetValue(VisibleInProperty, visibleIn);
        }

        public static FrameworkVisibility GetVisibleIn(DependencyObject element)
        {
            return (FrameworkVisibility)element.GetValue(VisibleInProperty);
        }

        private static void OnVisibleInPropertyChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
#if SILVERLIGHT
            var visibility = ((FrameworkVisibility) e.NewValue) == FrameworkVisibility.Wpf ? Visibility.Collapsed : Visibility.Visible;
#else
            var visibility = ((FrameworkVisibility) e.NewValue) == FrameworkVisibility.Silverlight ? Visibility.Collapsed : Visibility.Visible;
#endif

            (d as UIElement).Visibility = visibility;
        }
    }
}
