﻿// *************************************************************************************
// SCICHART © Copyright ABT Software Services Ltd. 2011-2012. All rights reserved.
//  
// Web: http://www.scichart.com
// Support: info@abtsoftware.co.uk
//  
// ToggleButtonExtensions.cs is part of SciChart Examples, a High Performance WPF & Silverlight Chart. 
// For full terms and conditions of the SciChart license, see http://www.scichart.com/scichart-eula/
//  
// SciChart Examples source code is provided free of charge on an "As-Is" basis to support
// and provide examples of how to use the SciChart component. You bear the risk of using it. 
// The authors give no express warranties, guarantees or conditions. You may have additional 
// consumer rights under your local laws which this license cannot change. To the extent 
// permitted under your local laws, the contributors exclude the implied warranties of 
// merchantability, fitness for a particular purpose and non-infringement. 
// *************************************************************************************
using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls.Primitives;

namespace Abt.Controls.SciChart.Example.Common
{
    // Attached property to mimic radio grouping on toggle buttons
    // Taken from here: http://www.bradcunningham.net/2009/09/grouping-and-checkboxes-in-wpf.html
    public class ToggleButtonExtensions : DependencyObject
    {
        public static Dictionary<ToggleButton, String> ElementToGroupNames = new Dictionary<ToggleButton, String>();

        public static readonly DependencyProperty GroupNameProperty =
            DependencyProperty.RegisterAttached("GroupName",
                                                typeof(String),
                                                typeof(ToggleButtonExtensions),
                                                new PropertyMetadata(String.Empty, OnGroupNameChanged));

        public static void SetGroupName(ToggleButton element, String value)
        {
            element.SetValue(GroupNameProperty, value);
        }

        public static String GetGroupName(ToggleButton element)
        {
            return element.GetValue(GroupNameProperty).ToString();
        }

        private static void OnGroupNameChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            //Add an entry to the group name collection
            var toggleButton = d as ToggleButton;
            if (toggleButton == null) return;

            String newGroupName = e.NewValue.ToString();
            String oldGroupName = e.OldValue.ToString();

            if (String.IsNullOrEmpty(newGroupName))
            {
                //Removing the toggle button from grouping
                RemoveCheckboxFromGrouping(toggleButton);
            }
            else
            {
                //Switching to a new group
                if (newGroupName != oldGroupName)
                {
                    if (!String.IsNullOrEmpty(oldGroupName))
                    {
                        //Remove the old group mapping
                        RemoveCheckboxFromGrouping(toggleButton);
                    }

                    AddCheckboxToGrouping(toggleButton, e.NewValue.ToString());
                }
            }
        }

        private static void RemoveCheckboxFromGrouping(ToggleButton checkBox)
        {
            ElementToGroupNames.Remove(checkBox);
            checkBox.Click -= ToggleButtonChecked;
            checkBox.Checked -= ToggleButtonChecked;
        }

        private static void AddCheckboxToGrouping(ToggleButton checkBox, string groupName)
        {
            ElementToGroupNames.Add(checkBox, groupName);
            checkBox.Click += ToggleButtonChecked;
            checkBox.Checked += ToggleButtonChecked;
        }

        static void ToggleButtonChecked(object sender, RoutedEventArgs e)
        {
            var toggleButton = e.OriginalSource as ToggleButton;
            foreach (var item in ElementToGroupNames)
            {
                if (item.Value == GetGroupName(toggleButton))
                {
                    item.Key.IsChecked = (item.Key == toggleButton);
                }
            }
        }

    }
}