﻿// *************************************************************************************
// SCICHART © Copyright ABT Software Services Ltd. 2011-2012. All rights reserved.
//  
// Web: http://www.scichart.com
// Support: info@abtsoftware.co.uk
//  
// Transition.cs is part of SciChart Examples, a High Performance WPF & Silverlight Chart. 
// For full terms and conditions of the SciChart license, see http://www.scichart.com/scichart-eula/
//  
// SciChart Examples source code is provided free of charge on an "As-Is" basis to support
// and provide examples of how to use the SciChart component. You bear the risk of using it. 
// The authors give no express warranties, guarantees or conditions. You may have additional 
// consumer rights under your local laws which this license cannot change. To the extent 
// permitted under your local laws, the contributors exclude the implied warranties of 
// merchantability, fitness for a particular purpose and non-infringement. 
// *************************************************************************************
using System.Windows;

namespace Abt.Controls.SciChart.Example.Common
{
    public class Transition : FrameworkElement
    {
        public enum TransitionState
        {
            A,
            B
        }

        public static DependencyProperty SourceProperty;
        public static DependencyProperty DisplayAProperty;
        public static DependencyProperty DisplayBProperty;
        public static DependencyProperty StateProperty;

        public object Source
        {
            get { return this.GetValue(SourceProperty); }
            set { this.SetValue(SourceProperty, value); }
        }

        public object DisplayA
        {
            get { return this.GetValue(DisplayAProperty); }
            set { this.SetValue(DisplayAProperty, value); }
        }

        public object DisplayB
        {
            get { return this.GetValue(DisplayBProperty); }
            set { this.SetValue(DisplayBProperty, value); }
        }

        public TransitionState State
        {
            get { return (TransitionState)this.GetValue(StateProperty); }
            set { this.SetValue(StateProperty, value); }
        }

        private void Swap()
        {
            if (this.State == TransitionState.A)
            {
                this.DisplayB = this.Source;
                this.State = TransitionState.B;
            }
            else
            {
                this.DisplayA = this.Source;
                this.State = TransitionState.A;
            }
        }

        static Transition()
        {
            SourceProperty = DependencyProperty.Register(
                "Source",
                typeof(object),
                typeof(Transition),
                new PropertyMetadata(
                    delegate(DependencyObject obj, DependencyPropertyChangedEventArgs args)
                    {
                        ((Transition)obj).Swap();
                    }));

            DisplayAProperty = DependencyProperty.Register(
                "DisplayA",
                typeof(object),
                typeof(Transition), 
                new PropertyMetadata(null));

            DisplayBProperty = DependencyProperty.Register(
                "DisplayB",
                typeof(object),
                typeof(Transition),
                new PropertyMetadata(null));

            StateProperty = DependencyProperty.Register(
                "State",
                typeof(TransitionState),
                typeof(Transition),
                new PropertyMetadata(TransitionState.A));
        }
    }
}
