﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Xml;
using System.Xml.Serialization;

namespace Abt.Controls.SciChart.Example
{
    public class ExampleLoader
    {
        public ExampleDefinition Parse(string xmlExample)
        {
            return Deserialize(xmlExample);
        }

        private ExampleDefinition Deserialize(string def)
        {
            var deserializer = new XmlSerializer(typeof(ExampleDefinition));

/*            var example = new ExampleDefinition {Description=" This is a richTextBox. And this is a <Hyperlink NavigateUri=\"http://www.microsoft.com\">Hyperlink</Hyperlink>"};
            var stringWriter = new StringWriter();
            var xmlWriter = XmlWriter.Create(stringWriter);
            deserializer.Serialize(xmlWriter, example);
            var str = stringWriter.GetStringBuilder().ToString();*/


            var stringReader = new StringReader(def);
            var xmlReader = XmlReader.Create(stringReader);

            var res = deserializer.Deserialize(xmlReader) as ExampleDefinition;

            xmlReader.Close();
            stringReader.Close();

            return res;
        }

        public static string LoadSourceFile(string name)
        {
            Assembly assembly = typeof(ExampleLoader).Assembly;

            var names = assembly.GetManifestResourceNames();

            var allExampleSourceFiles = names.Where(x => x.Contains("ExampleSourceFiles"));

            var find = name.Replace('/', '.').Replace(".cs.", ".c.");
            var file = allExampleSourceFiles.FirstOrDefault(x => x.Contains(find));

            if (file == null)
                throw new Exception(string.Format("Unable to find the source code resource {0}", find));

            using (var s = assembly.GetManifestResourceStream(file))
            using (var sr = new StreamReader(s))
            {
                return sr.ReadToEnd();
            }
        }

        public IDictionary<string, string> DiscoverAllXmlFiles()
        {
            return DiscoverAllExampleDefinitions();
        }

        private IDictionary<string, string> DiscoverAllExampleDefinitions()
        {
            var dict = new Dictionary<string, string>();
            Assembly assembly = typeof (ExampleLoader).Assembly;

            var names = assembly.GetManifestResourceNames();

            var allXmlManifestResources = names.Where(x => x.Contains("ExampleDefinitions")).ToList();
            allXmlManifestResources.Sort();

            foreach(var xmlResource in allXmlManifestResources)
            {
                using (var s = assembly.GetManifestResourceStream(xmlResource))
                using (var sr = new StreamReader(s))
                {
                    dict.Add(
                        xmlResource.Replace("Abt.Controls.SciChart.Example.Resources.ExampleDefinitions.", string.Empty),
                        sr.ReadToEnd());
                }
            }
            return dict;
        }
    }
}
