﻿using System;
using System.Globalization;
using System.Linq;
using System.Text.RegularExpressions;
using System.Windows.Input;
using Abt.Controls.SciChart.Example.MVVM;

namespace Abt.Controls.SciChart.Example
{
    public class ExampleSearchViewModel : BaseViewModel, ISelectable
    {
        private string _name;
        private string _group;
        private string _feature;
        private string _chartType;
        private string _description;

        public Example Example { get; set; }

        public ICommand SelectCommand
        {
            get { return new ActionCommand(() => Example.SelectCommand.Execute(Example)); }
            set { throw new NotImplementedException(); }
        }

        #region Search interface

        public bool IsMatch { get; set; }

        public string Name
        {
            get { return _name; }
            set
            {
                if (_name != value)
                {
                    _name = value;
                    OnPropertyChanged("Name");
                }
            }
        }

        public string Group
        {
            get { return _group; }
            set
            {
                if (_group != value)
                {
                    _group = value;
                    OnPropertyChanged("Group");
                }
            }
        }

        public string Feature
        {
            get { return _feature; }
            set
            {
                if (_feature != value)
                {
                    _feature = value;
                    OnPropertyChanged("Feature");
                }
            }
        }

        public string ChartType
        {
            get { return _chartType; }
            set
            {
                if (_chartType != value)
                {
                    _chartType = value;
                    OnPropertyChanged("ChartType");
                }
            }
        }

        public string Description
        {
            get { return _description; }
            set
            {
                if (_description != value)
                {
                    _description = value;
                    OnPropertyChanged("Description");
                }
            }
        }

        #endregion

        public static bool IsAutocompleteSuggestion(string searchText, object exampleItem)
        {
            var result = false;

            var example = exampleItem as ExampleSearchViewModel;
            const string pattern = @"\b{0}";

            if (example != null)
            {
                var parts = searchText.Split(new[] { ' ' }, StringSplitOptions.RemoveEmptyEntries);

                example.CleanSearchResults();

                foreach (var part in parts)
                {
                    example.IsMatch = false;

                    var regex = new Regex(String.Format(pattern, part),
                      RegexOptions.IgnoreCase);

                    example.CompareName(regex);
                    example.CompareGroup(regex);
                    example.CompareFeature(regex);
                    example.CompareChartType(regex);
                    example.CompareDescription(regex);

                    result = result || example.IsMatch;
                }
            }

            return result;
        }

        private void CleanSearchResults()
        {
            ChartType = "";
            Feature = "";
            Group = "";
            Description = "";
        }

        private void CompareName(Regex regex)
        {
            if(regex.IsMatch(Example.ExampleDisplayName))
            {
                IsMatch = true;
            }
        }

        private void CompareGroup(Regex regex)
        {
            if (regex.IsMatch(Example.Group.ToString()))
            {
                Group = String.Format(CultureInfo.InvariantCulture, "{0}...", Example.Group);
                IsMatch = true;
            }
        }

        private void CompareFeature(Regex regex)
        {
            //TODO: 
        }

        private void CompareChartType(Regex regex)
        {
            var chartsMatch = Enum.GetValues(typeof (ChartTypes))
                .Cast<ChartTypes?>()
                .Where(memb => Example.UsedChartTypes.HasFlag(memb))
                .Where(exist => regex.IsMatch(String.Format(CultureInfo.InvariantCulture, "{0}", exist)))
                .FirstOrDefault();

            if (chartsMatch != null)
            {
                ChartType = String.Format(CultureInfo.InvariantCulture, "{0}...",
                                  chartsMatch.Value);
                IsMatch = true;
            }
        }

        private void CompareDescription(Regex regex)
        {
            var descMatch = regex.Match(Example.ExampleToolTipDescription);

            if (descMatch.Success)
            {
                const int wordsBefore = 1;
                const int wordsAfter = 3;
                const int minCharsPerWord = 2;

                string wordPattern = @"\b\w{" + minCharsPerWord + @",}\b";

                var index = descMatch.Index;
                var matchEndIndex = index + descMatch.Length;

                var wordsBeforeMatch = GetWordsIn(wordPattern, Example.ExampleToolTipDescription.Substring(0, index));
                var count = wordsBeforeMatch.Count;
                var lastElemIndex = count - 1;
                var first = count > 0 ? wordsBeforeMatch[Math.Max(lastElemIndex, lastElemIndex - wordsBefore)].Index : 0;

                var wordsAfterMatch = GetWordsIn(wordPattern, Example.ExampleToolTipDescription.Substring(matchEndIndex, Example.ExampleToolTipDescription.Length - matchEndIndex));
                count = wordsAfterMatch.Count;
                lastElemIndex = count - 1;
                var last = count > 0 ? matchEndIndex + wordsAfterMatch[Math.Min(lastElemIndex, wordsAfter)].Index : Example.ExampleToolTipDescription.Length;

                Description =
                    String.Format(CultureInfo.InvariantCulture, "{0}...",
                                  Example.ExampleToolTipDescription.Substring(first, last - first));
                IsMatch = true;
            }
        }

        private MatchCollection GetWordsIn(string wordPattern , string input)
        {
            return Regex.Matches(input, wordPattern);
        }
    }
}
