﻿using System.Collections.ObjectModel;
using System.Windows.Input;
using Abt.Controls.SciChart.Example.Common;
using Abt.Controls.SciChart.Example.Data;
using Abt.Controls.SciChart.Example.MVVM;

namespace Abt.Controls.SciChart.Example.Examples.IWantTo.CreateStockCharts.MultiPane
{
    public class CreateMultiPaneStockChartsViewModel : BaseViewModel
    {
        private string _theme;
        private IndexRange xAxisVisibleRange;
        private ObservableCollection<BaseChartPaneViewModel> _chartPaneViewModels = new ObservableCollection<BaseChartPaneViewModel>();
        private ICommand _closePaneCommand;

        public CreateMultiPaneStockChartsViewModel()
        {
            _closePaneCommand = new ActionCommand<IChildPane>(pane => ChartPaneViewModels.Remove((BaseChartPaneViewModel)pane));

            // Get prices and append for the main price chart (Candlestick)
            var instrumentPriceData = DataManager.Instance.GetPriceData(Instrument.EurUsd.Value, TimeFrame.Hourly);
            _chartPaneViewModels.Add(new PricePaneViewModel(this, instrumentPriceData) { IsFirstChartPane = true });
            _chartPaneViewModels.Add(new VolumePaneViewModel(this, instrumentPriceData) {Title="Volume", ClosePaneCommand = _closePaneCommand });
            _chartPaneViewModels.Add(new IndicatorPaneViewModel(this, instrumentPriceData) {Title="Indicator", ClosePaneCommand = _closePaneCommand });

            SelectedTheme = "BrightSpark";
        }

        public string SelectedTheme
        {
            get { return _theme; }
            set
            {
                if (_theme == value) return;

                _theme = value;
                OnPropertyChanged("SelectedTheme");
            }
        }

        public IndexRange XVisibleRange
        {
            get { return xAxisVisibleRange; }
            set
            {
                if (xAxisVisibleRange == value) return;

                xAxisVisibleRange = value;
                OnPropertyChanged("XVisibleRange");
            }
        }
        

        public ObservableCollection<BaseChartPaneViewModel> ChartPaneViewModels
        {
            get { return _chartPaneViewModels; }
            set
            {
                if (_chartPaneViewModels == value) return;

                _chartPaneViewModels = value;
                OnPropertyChanged("ChartPaneViewModels");
            }
        }
    }
}
