﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace Abt.Controls.SciChart.Example.Examples.IWantTo.InspectDatapoints
{
    public partial class HitTestDatapoints : UserControl
    {
        public HitTestDatapoints()
        {
            InitializeComponent();

            // Append some data
            var dataset = new DataSeriesSet<double, double>();
            var series = dataset.AddSeries();
            series.Append(new double[] { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 }, new double[] { 0, 0.1, 0.3, 0.5, 0.4, 0.35, 0.3, 0.25, 0.2, 0.1, 0.05 });
            sciChartSurface.DataSet = dataset;

            // On click, perform a hit-test
            sciChartSurface.MouseLeftButtonUp += SciChartSurfaceMouseLeftButtonUp;
        }

        private void SciChartSurfaceMouseLeftButtonUp(object sender, MouseButtonEventArgs e)
        {
            // Hit tests are done per renderable series, so get the first renderable series (defined in Xaml)
            var renderableSeries = this.sciChartSurface.RenderableSeries[0];

            // Perform the hit test relative to the GridLinesPanel
            Point mousePoint = e.GetPosition(sciChartSurface.GridLinesPanel as UIElement);
            var hitTest = renderableSeries.HitTest(mousePoint);

            // Output results 
            string formattedString =
                string.Format("Mouse Coord: {0:0}, {1:0}\t\tNearest Datapoint Coord: {2}, {3}\tData Value: {4}, {5}\t\tIsHit? {6}",
                              mousePoint.X, mousePoint.Y,
                              hitTest.HitTestPoint.X, hitTest.HitTestPoint.Y,
                              hitTest.XValue, hitTest.YValue,
                              hitTest.IsHit);

            var newItem = new ListBoxItem() {Content = formattedString};
            hitTestListbox.Items.Add(newItem);

            hitTestListbox.ScrollIntoView(newItem);
        }        
    }
}
