﻿using System;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using Abt.Controls.SciChart.Example.Data;

namespace Abt.Controls.SciChart.Example.Examples.IWantTo.ManipulateSeries
{
    /// <summary>
    /// Interaction logic for AddRemoveDataSeriesExampleView.xaml
    /// </summary>
    public partial class AddRemoveDataSeriesExampleView : UserControl
    {
        public AddRemoveDataSeriesExampleView()
        {
            InitializeComponent();
            this.Loaded += SciChartSurfaceLoaded;
        }

        private void SciChartSurfaceLoaded(object sender, RoutedEventArgs e)
        {
            if (sciChartSurface.DataSet == null)
            {
                sciChartSurface.DataSet = new DataSeriesSet<double, double>();
            }
            sciChartSurface.DataSet.Clear();
        }

        private void DeleteSeriesClick(object sender, RoutedEventArgs e)
        {
            var rSeries = sciChartSurface.SelectedRenderableSeries.FirstOrDefault();
            if (rSeries == null || rSeries.DataSeries == null) 
                return;

            sciChartSurface.DataSet.Remove(rSeries.DataSeries);
            sciChartSurface.RenderableSeries.Remove(rSeries);

            // Re-order dataseries indices after remove
            // This caveat is discussed in detail at http://www.scichart.com/how-to-add-and-remove-chart-series-dynamically/
            // and is unique to v1.x of SciChart. In v2.0 we will be altering the DataSeries API to resolve this issue
            for (int i = 0; i < sciChartSurface.RenderableSeries.Count; i++)
            {
                sciChartSurface.RenderableSeries[i].DataSeriesIndex = i;
            }

            sciChartSurface.ZoomExtents();

            OnSeriesSelectionChanged();
        }

        private void OnSeriesSelectionChanged()
        {
            bool hasSelection = sciChartSurface.SelectedRenderableSeries.Any();

            deleteSeriesButton.IsEnabled = hasSelection;
        }

        private void AddSeriesClick(object sender, RoutedEventArgs e)
        {
            var dataSeries = new XyDataSeries<double, double>();
            
            var doubleData = DataManager.Instance.GetRandomDoubleSeries(250);
            
            dataSeries.Append(doubleData.XData, doubleData.YData);
            sciChartSurface.DataSet.Add(dataSeries);

            // TODO: Alternative API? How can we do operations like selection, set point marker template, styling etc... 
            //dataSeries.RenderAs = new LineSeries() { SeriesColor = DataManager.Instance.GetRandomColor() };
            var renderSeries = new FastLineRenderableSeries {SeriesColor = DataManager.Instance.GetRandomColor()};
            sciChartSurface.RenderableSeries.Add(renderSeries);

            // TODO: Select newly added series?

            sciChartSurface.ZoomExtents();
        }

        private void SeriesSelectionModifier_SelectionChanged(object sender, EventArgs e)
        {
            OnSeriesSelectionChanged();
        }
    }
}
