﻿using System;
using System.Windows;
using System.Windows.Controls;
using Abt.Controls.SciChart.Example.Data;

namespace Abt.Controls.SciChart.Example.Examples.IWantTo.ModifyAxisBehaviour
{
    public partial class LogarithmicAxisView : UserControl
    {
        private static readonly TimeSpan ts = TimeSpan.FromMilliseconds(500);

        public LogarithmicAxisView()
        {
            InitializeComponent();
        }

        private void LogarithmicAxisView_Loaded(object sender, RoutedEventArgs e)
        {
            // Create a dataset of type X=double, Y=double
            var dataSeriesSet = new DataSeriesSet<double, double>();
            sciChart.DataSet = dataSeriesSet;

            // Add a data series
            var dataSeries0 = dataSeriesSet.AddSeries();
            var dataSeries1 = dataSeriesSet.AddSeries();
            var dataSeries2 = dataSeriesSet.AddSeries();

            var data1 = DataManager.Instance.GetExponentialCurve(1.8, 100);
            var data2 = DataManager.Instance.GetExponentialCurve(2.25, 100);
            var data3 = DataManager.Instance.GetExponentialCurve(3.59, 100);

            // Append data to series.
            dataSeries0.Append(data1.XData, data1.YData);
            dataSeries1.Append(data2.XData, data2.YData);
            dataSeries2.Append(data3.XData, data3.YData);

            // Zoom to extents of the data
            sciChart.ZoomExtents();
        }

        private void YAxisLogChecked(object sender, RoutedEventArgs e)
        {
            if (yAxis != null) yAxis.AxisMode = AxisMode.Logarithmic;
            if (xAxis != null) xAxis.AxisMode = AxisMode.Linear;

            if (sciChart != null) { sciChart.AnimateZoomExtents(ts); } 
        }

        private void XAxisLogChecked(object sender, RoutedEventArgs e)
        {
            if (yAxis != null) yAxis.AxisMode = AxisMode.Linear;
            if (xAxis != null) xAxis.AxisMode = AxisMode.Logarithmic;

            if (sciChart != null) { sciChart.AnimateZoomExtents(ts); }
        }

        private void XYAxisLogChecked(object sender, RoutedEventArgs e)
        {
            if (yAxis != null) yAxis.AxisMode = AxisMode.Logarithmic;
            if (xAxis != null) xAxis.AxisMode = AxisMode.Logarithmic;

            if (sciChart != null) { sciChart.AnimateZoomExtents(ts); } 
        }

        private void NoneChecked(object sender, RoutedEventArgs e)
        {
            if (yAxis != null) yAxis.AxisMode = AxisMode.Linear;
            if (xAxis != null) xAxis.AxisMode = AxisMode.Linear;

            if (sciChart != null) { sciChart.AnimateZoomExtents(ts); }
        }
    }
}
