﻿using System;
using System.Windows;
using System.Windows.Controls;
using Abt.Controls.SciChart.Example.Common;
using Abt.Controls.SciChart.Example.Data;

namespace Abt.Controls.SciChart.Example.Examples.IWantTo.ModifyAxisBehaviour
{
    public partial class ModifyAxisProperties : UserControl
    {
        public ModifyAxisProperties()
        {
            InitializeComponent();
            cboAlignment.Items.Add(AxisAlignment.Right);
            cboAlignment.Items.Add(AxisAlignment.Left);
        }

        public void ModifyAxisPropertiesLoaded(object sender, EventArgs e)
        {
             using (sciChart.SuspendUpdates())
            {
                // Create a dataset of type x=DateTime, y=Double
                var dataSeriesSet = new DataSeriesSet<DateTime, double>();
                sciChart.DataSet = dataSeriesSet;

                // Add a data series
                var dataSeries0 = dataSeriesSet.AddSeries();
                var dataSeries1 = dataSeriesSet.AddSeries<OhlcDataSeries<DateTime, double>>();
                var dataSeries2 = dataSeriesSet.AddSeries();

                var dataSource = DataManager.Instance;

                // Prices are in the format Time, Open, High, Low, Close (all IList)            
                var prices = dataSource.GetPriceData(Instrument.Indu.Value, TimeFrame.Daily);

                // Append data to series.                 
                dataSeries0.Append(prices.TimeData, dataSource.Offset(prices.LowData, -1000));
                dataSeries1.Append(prices.TimeData, prices.OpenData, prices.HighData, prices.LowData, prices.CloseData);                
                dataSeries2.Append(prices.TimeData, dataSource.ComputeMovingAverage(prices.CloseData, 50));                                

                sciChart.ZoomExtents();
            }
        }

        private void OnMinXRangeChanged(object sender, SelectionChangedEventArgs e)
        {
/*            var selectedDate = (sender as CompatibleDatePicker).SelectedDate;

            if (!SetVisibleRange(xAxis, selectedDate, xAxis.VisibleRange.Max))
            {
                minDatePicker.SelectedDate = (DateTime)xAxis.VisibleRange.Min;
            }*/
        }

        private void OnMaxXRangeChanged(object sender, SelectionChangedEventArgs e)
        {
           /* var selectedDate = (sender as CompatibleDatePicker).SelectedDate;

            if(!SetVisibleRange(xAxis, xAxis.VisibleRange.Min, selectedDate))
            {
                maxDatePicker.SelectedDate = (DateTime)xAxis.VisibleRange.Max;
            }*/
        }

        private void OnMinYAxesChanged(object sender, RoutedEventArgs e)
        {
            double value;
            var isPositiveDouble = double.TryParse((sender as TextBox).Text, out value) && value >= 0;

            if (!SetVisibleRange(yAxis, isPositiveDouble ? value : yAxis.VisibleRange.Min, yAxis.VisibleRange.Max))
            {
                minValueTb.Text = yAxis.VisibleRange.Min.ToString();
            }
        }

        private void OnMaxYAxesChanged(object sender, RoutedEventArgs e)
        {
            double value;
            var isDouble = double.TryParse((sender as TextBox).Text, out value) && value >= 0;

            if (!SetVisibleRange(yAxis, yAxis.VisibleRange.Min, isDouble ? value : yAxis.VisibleRange.Max))
            {
                maxValueTb.Text = yAxis.VisibleRange.Max.ToString();
            }
        }

        private bool SetVisibleRange(IAxis axis, IComparable min, IComparable max)
        {
            if (CheckVisibleRange(min, max))
            {
                axis.VisibleRange = RangeFactory.NewWithMinMax(axis.VisibleRange, min, max);

                return true;
            }

            return false;
        }

        private bool CheckVisibleRange(IComparable min, IComparable max)
        {
            return min.CompareTo(max) < 0;
        }

        private void OnXVisibleRangeChanged(object sender, VisibleRangeChangedEventArgs e)
        {
           ((ToValidDateTimeConverter)grid.Resources["ToValidDateTimeConverter"]).XVisibleRange = (DateRange)xAxis.VisibleRange;
        }
    }
}
