﻿using System;
using System.Windows;
using System.Windows.Controls;

namespace Abt.Controls.SciChart.Example.Examples.IWantTo.ModifyAxisBehaviour
{
    public partial class QuadLeftRightAxes : UserControl
    {
        // Used to generate Random Walk
        private Random _random = new Random(251916);
        const int Count = 2000;

        public QuadLeftRightAxes()
        {
            InitializeComponent();
        }

        private void QuadLeftRightAxes_Loaded(object sender, RoutedEventArgs e)
        {
            if (sciChart.DataSet != null)
            {
                return;
            }

            // Batch updates with one redraw
            using (sciChart.SuspendUpdates())
            {
                var dataset1 = new DataSeriesSet<DateTime, double>();

                // Add four data-series
                var dataSeries0 = dataset1.AddSeries();
                var dataSeries1 = dataset1.AddSeries();
                var dataSeries2 = dataset1.AddSeries();
                var dataSeries3 = dataset1.AddSeries();
                var dataSeries4 = dataset1.AddSeries();
                var dataSeries5 = dataset1.AddSeries();
                var dataSeries6 = dataset1.AddSeries();
                var dataSeries7 = dataset1.AddSeries();


                // Fill each dataset with 2,000 pts of X,Y values (Date,Double)
                FillData(dataSeries0, "Red Line");
                FillData(dataSeries1, "Black Line");
                FillData(dataSeries2, "Orange Line");
                FillData(dataSeries3, "Blue Line");
                FillData(dataSeries4, "Another Blue");
                FillData(dataSeries5, "Green Line");
                FillData(dataSeries6, "Another Red");
                FillData(dataSeries7, "Another Black");

                sciChart.DataSet = dataset1;
            }
        }

        private void FillData(IXyDataSeries<DateTime, double> dataSeries, string name)
        {
            double randomWalk = 10.0;
            var startDate = new DateTime(2012, 01, 01);

            // Generate the X,Y data with sequential dates on the X-Axis and slightly positively biased random walk on the Y-Axis
            var xBuffer = new DateTime[Count];
            var yBuffer = new double[Count];
            for (int i = 0; i < Count; i++)
            {
                randomWalk += (_random.NextDouble() - 0.498);
                yBuffer[i] = randomWalk;
                xBuffer[i] = startDate.AddMinutes(i * 10);
            }

            // Buffer above and append all in one go to avoid multiple recalculations of series range
            dataSeries.Append(xBuffer, yBuffer);
            dataSeries.SeriesName = name;
        }
    }
}
