﻿using System;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using Abt.Controls.SciChart.Example.Common;
using Abt.Controls.SciChart.Example.Data;

namespace Abt.Controls.SciChart.Example.Examples.IWantTo.StyleAChart
{
    public partial class ChangeTheme : UserControl
    {
        public ChangeTheme()
        {
            InitializeComponent();

            // Fill theme combo box and set default theme
            foreach (string theme in ThemeManager.AllThemes)
            {
                cboTheme.Items.Add(theme);
            }
            cboTheme.SelectedItem = "ExpressionLight";
        }

        private void ChangeTheme_Loaded(object sender, RoutedEventArgs e)
        {
            using (sciChart.SuspendUpdates())
            {
                // Create a dataset of type x=DateTime, y=Double
                var dataSeriesSet = new DataSeriesSet<DateTime, double>();
                sciChart.DataSet = dataSeriesSet;

                // Add a data series
                var dataSeries0 = dataSeriesSet.AddSeries();
                dataSeries0.SeriesName = "Mountain Series";
                var dataSeries1 = dataSeriesSet.AddSeries<OhlcDataSeries<DateTime, double>>();
                dataSeries1.SeriesName = "Candlestick Series";
                var dataSeries2 = dataSeriesSet.AddSeries();
                dataSeries2.SeriesName = "Line Series";
                var dataSeries3 = dataSeriesSet.AddSeries();
                dataSeries3.SeriesName = "Column Series";

                var dataSource = DataManager.Instance;

                // Prices are in the format Time, Open, High, Low, Close (all IList)            
                var prices = dataSource.GetPriceData(Instrument.Indu.Value, TimeFrame.Daily);

                // Append data to series.                 
                dataSeries0.Append(prices.TimeData, dataSource.Offset(prices.LowData, -1000));
                dataSeries1.Append(prices.TimeData, prices.OpenData, prices.HighData, prices.LowData, prices.CloseData);                
                dataSeries2.Append(prices.TimeData, dataSource.ComputeMovingAverage(prices.CloseData, 50));                
                dataSeries3.Append(prices.TimeData, prices.VolumeData.Select(x => (double) x));

                overview.ParentSurface = sciChart;

                sciChart.ZoomExtents();
            }
        }

        private void cboThemeChanged(object sender, SelectionChangedEventArgs e)
        {
            ThemeManager.SetTheme(sciChart, (string)cboTheme.SelectedItem);
            ThemeManager.SetTheme(overview, (string)cboTheme.SelectedItem);
        }
    }
}
