﻿using System.Windows;
using System.Windows.Controls;
using Abt.Controls.SciChart.Example.Data;

namespace Abt.Controls.SciChart.Example.Examples.IWantTo.ZoomAndPanAChart
{
    public partial class MouseDragToPan : UserControl
    {
        public MouseDragToPan()
        {
            InitializeComponent();
        }

        private void MouseDragToPan_Loaded(object sender, RoutedEventArgs e)
        {
            // Performing multiple updates in a SuspendUpdates block is efficient as only one redraw is performed
            using (sciChart.SuspendUpdates())
            {
                // Create a dataset of type X=double, Y=double
                var dataSeriesSet = new DataSeriesSet<double, double>();
                sciChart.DataSet = dataSeriesSet;

                // Add some data series
                var dataSeries0 = dataSeriesSet.AddSeries();
                var dataSeries1 = dataSeriesSet.AddSeries();
                var dataSeries2 = dataSeriesSet.AddSeries();

                var data1 = DataManager.Instance.GetDampedSinewave(300, 1.0, 0.0, 0.01, 1000);
                var data2 = DataManager.Instance.GetDampedSinewave(300, 1.0, 0.0, 0.024, 1000);
                var data3 = DataManager.Instance.GetDampedSinewave(300, 1.0, 0.0, 0.049, 1000);

                // Append data to series.
                dataSeries0.Append(data1.XData, data1.YData);
                dataSeries1.Append(data2.XData, data2.YData);
                dataSeries2.Append(data3.XData, data3.YData);

                // Set initial zoom
                sciChart.XAxis.VisibleRange = new DoubleRange(3, 6);
                sciChart.ZoomExtentsY();
            }
        }

        // Optional: demonstrates changing which mouse button ZoomPanModifier reacts to
        private void MouseLeft_Checked(object sender, RoutedEventArgs e)
        {
            if (zoomPanModifier != null) zoomPanModifier.ExecuteOn = ExecuteOn.MouseLeftButton;
        }

        private void MouseMiddle_Checked(object sender, RoutedEventArgs e)
        {
            if (zoomPanModifier != null) zoomPanModifier.ExecuteOn = ExecuteOn.MouseMiddleButton;
        }

        private void MouseRight_Checked(object sender, RoutedEventArgs e)
        {
            if (zoomPanModifier != null) zoomPanModifier.ExecuteOn = ExecuteOn.MouseRightButton;
        }
    }
}
