﻿using System;
using Abt.Controls.SciChart.Example.MVVM;

namespace Abt.Controls.SciChart.Example.Examples.IWantTo.ZoomAndPanAChart
{
    public class SynchronizeMouseAcrossChartsViewModel : BaseViewModel
    {
        private bool _mouseWheelEnabled;
        private bool _panEnabled;
        private bool _rolloverEnabled;
        private bool _cursorEnabled;
        private bool _zoomEnabled;
        private IRange _sharedXVisibleRange;
        private readonly IDataSeriesSet _chartData0;
        private readonly IDataSeriesSet _chartData1;

        public SynchronizeMouseAcrossChartsViewModel()
        {
            // Create two datasets which we bind to in the view
            _chartData0 = CreateDataset();
            _chartData1 = CreateDataset();

            // Set default ChartModifier state
            this.MouseWheelEnabled = false;
            this.PanEnabled = true;
            this.CursorEnabled = true;

            // Set shared initial XAxis.VisibleRange. 
            // Note in code-behind we call sciChartSurface.AnimateZoomExtents(), which requires a
            // valid initial range, hence this binding
            SharedXVisibleRange = new DoubleRange(0,1);
        }

        public IDataSeriesSet ChartData0 { get { return _chartData0; } }
        public IDataSeriesSet ChartData1 { get { return _chartData1; } }

        public IRange SharedXVisibleRange
        {
            get { return _sharedXVisibleRange; }
            set
            {
                if (_sharedXVisibleRange == value) return;
                _sharedXVisibleRange = value;
                OnPropertyChanged("SharedXVisibleRange");
            }
        }
        
        public bool MouseWheelEnabled
        {
            get { return _mouseWheelEnabled; }
            set
            {
                if (_mouseWheelEnabled == value) return;
                _mouseWheelEnabled = value;
                OnPropertyChanged("MouseWheelEnabled");
            }
        }

        public bool PanEnabled
        {
            get { return _panEnabled; }
            set
            {
                if (_panEnabled == value) return;
                _panEnabled = value;
                OnPropertyChanged("PanEnabled");

                // Toggle Zoom off
                ZoomEnabled = !PanEnabled;
            }
        }

        public bool ZoomEnabled
        {
            get { return _zoomEnabled; }
            set
            {
                if (_zoomEnabled == value) return;
                _zoomEnabled = value;
                OnPropertyChanged("ZoomEnabled");

                // Toggle pan off
                PanEnabled = !ZoomEnabled;
            }
        }

        public bool CursorEnabled
        {
            get { return _cursorEnabled; }
            set
            {
                if (_cursorEnabled == value) return;
                _cursorEnabled = value;
                OnPropertyChanged("CursorEnabled");

                // Toggle RolloverEnabled off
                RolloverEnabled = !CursorEnabled;
            }
        }

        public bool RolloverEnabled
        {
            get { return _rolloverEnabled; }
            set
            {
                if (_rolloverEnabled == value) return;
                _rolloverEnabled = value;
                OnPropertyChanged("RolloverEnabled");

                // Toggle RolloverEnabled off
                CursorEnabled = !RolloverEnabled;
            }
        }

        private IDataSeriesSet CreateDataset()
        {
            var ds = new DataSeriesSet<double, double>();
            var ds0 = ds.AddSeries();

            const int count = 1000;
            for (int i = 0; i < count; i++)
            {
                ds0.Append(i, count * Math.Sin(i * Math.PI * 0.1) / i);
            }

            return ds;
        }
    }
}
