﻿using System;
using System.Windows;
using CodeHighlighter;

namespace Abt.Controls.SciChart.Example.Helpers
{
    public class CodeHighlighter: FrameworkElement
    {
        public static readonly DependencyProperty SourceLanguageProperty =
    DependencyProperty.RegisterAttached(
        "SourceLanguage",
        typeof(SourceLanguageType),
        typeof(CodeHighlighter),
        new PropertyMetadata(SourceLanguageType.CSharp, OnSourceLanguagePropertyChanged));

        public static readonly DependencyProperty SourceCodeProperty =
            DependencyProperty.RegisterAttached(
                "SourceCode",
                typeof(string),
                typeof(CodeHighlighter),
                new PropertyMetadata(string.Empty, OnSourceCodePropertyChanged));

        public static string GetSourceCode(DependencyObject o)
        {
            return (string)o.GetValue(SourceCodeProperty);
        }

        public static void SetSourceCode(DependencyObject o, string code)
        {
            o.SetValue(SourceCodeProperty, code);
        }

        public static SourceLanguageType GetSourceLanguage(DependencyObject o)
        {
            return (SourceLanguageType)o.GetValue(SourceCodeProperty);
        }

        public static void SetSourceLanguage(DependencyObject o, SourceLanguageType lang)
        {
            o.SetValue(SourceLanguageProperty, lang);
        }

        private static void OnSourceLanguagePropertyChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var value = (SourceLanguageType)e.NewValue;

            if (!Enum.IsDefined(typeof(SourceLanguageType), value))
            {
                throw new ArgumentException("Invalid source language type.");
            }

            if (e.NewValue != e.OldValue)
            {
                SetSourceLanguage(d, value);
            }
        }

        private static void OnSourceCodePropertyChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            SetSourceCode(d, (string)e.NewValue);
        }
    }
}
