﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Markup;

namespace Abt.Controls.SciChart.Example.Helpers
{
    public class RichTextBoxHelper
    {
        public static readonly DependencyProperty TextProperty = DependencyProperty.RegisterAttached("Text", typeof(string), typeof(RichTextBoxHelper), new PropertyMetadata(null, OnTextChanged));

        public static string GetText(DependencyObject o)
        {
            return (string)o.GetValue(TextProperty);
        }

        public static void SetText(DependencyObject o, string value)
        {
            o.SetValue(TextProperty, value);
        }

        private static void OnTextChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var rtb = d as RichTextBox;
            if (rtb != null)
            {
#if !SILVERLIGHT
                rtb.IsDocumentEnabled = true;
#endif
                var text = (string)e.NewValue;
                var xamlString = GetXamlFrom(text);

                LoadXamlInto(rtb, xamlString);

                HookHyperlinks(
#if SILVERLIGHT
                    rtb.Blocks[0] as Paragraph
#else
                    rtb.Document.Blocks.FirstBlock as Paragraph
#endif
                    );

#if SILVERLIGHT
                //Scroll RichTextBox to top
                rtb.Selection.Select(rtb.ContentStart, rtb.ContentStart);
#endif
            }
        }

        private static void LoadXamlInto(RichTextBox rtb, string xamlStr)
        {
#if !SILVERLIGHT
            var msDocument = new MemoryStream((new ASCIIEncoding()).GetBytes(xamlStr));

            var formattedDocument = XamlReader.Load(msDocument) as

                                    FlowDocument;

            rtb.Document = formattedDocument;

            msDocument.Close();
#else
            var formattedDocument = XamlReader.Load(xamlStr) as
            Paragraph;

            rtb.Blocks.Clear();
            rtb.Blocks.Add(formattedDocument);
#endif
        }

        private static string GetXamlFrom(string text)
        {
            var xamlStr = new StringBuilder();

#if !SILVERLIGHT
            xamlStr.Append("<FlowDocument xmlns=\"http://schemas.microsoft.com/winfx/2006/xaml/presentation\">");
#endif
            xamlStr.Append("<Paragraph xmlns=\"http://schemas.microsoft.com/winfx/2006/xaml/presentation\">");
            xamlStr.Append(text);
            xamlStr.Append("</Paragraph>");
#if !SILVERLIGHT
            xamlStr.Append("</FlowDocument>");
#endif
            return xamlStr.ToString();
        }

        private static void HookHyperlinks(Paragraph paragraph)
        {
            var hyperlinks = paragraph.Inlines.OfType<Hyperlink>();

            foreach (var hyperlink in hyperlinks)
            {
                hyperlink.Command = new ActionCommand<Hyperlink>(link => Navigator.Instance.Navigate(
                    ex =>
                    ex.ExampleDisplayName == link.TargetName));
                hyperlink.CommandParameter = hyperlink;
            }
        }
    }
}
