﻿// *************************************************************************************
// SCICHART © Copyright ABT Software Services Ltd. 2011-2012. All rights reserved.
//  
// Web: http://www.scichart.com
// Support: info@abtsoftware.co.uk
//  
// MainViewModel.cs is part of SciChart Examples, a High Performance WPF & Silverlight Chart. 
// For full terms and conditions of the SciChart license, see http://www.scichart.com/scichart-eula/
//  
// SciChart Examples source code is provided free of charge on an "As-Is" basis to support
// and provide examples of how to use the SciChart component. You bear the risk of using it. 
// The authors give no express warranties, guarantees or conditions. You may have additional 
// consumer rights under your local laws which this license cannot change. To the extent 
// permitted under your local laws, the contributors exclude the implied warranties of 
// merchantability, fitness for a particular purpose and non-infringement. 
// *************************************************************************************

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Windows.Input;
using Abt.Controls.SciChart.Example.Helpers;
using Abt.Controls.SciChart.Example.MVVM;

namespace Abt.Controls.SciChart.Example
{
    public class ConsoleLogger : ISciChartLoggerFacade
    {
        public void Log(string formatString, params object[] args)
        {
            Debug.WriteLine(formatString, args);
        }
    }

    public class MainViewModel : BaseViewModel
    {
        private Example _selectedExample;

        private ActionCommand _goHome;
        private ActionCommand _goBack;
        private ActionCommand _goForward;
        private bool _isHomePage;
        private int _selectedIndex;

        public MainViewModel()
        {
            // NOTE: Uncomment to enable debug logging. This will have an adverse effect on performance 
            //Abt.Controls.SciChart.Utility.SciChartDebugLogger.Instance.SetLogger(new ConsoleLogger());

            _goHome = new ActionCommand(() =>
                                            {
                                                Navigator.Instance.Navigate(ApplicationPage.HomePageId);
                                                SelectedIndex = 0;
                                            },
                                        () => Navigator.Instance.CanNavigateTo(ApplicationPage.HomePageId));

            _goBack = new ActionCommand(()=>
                                            {
                                                Navigator.Instance.GoBack();
                                                SelectedIndex = 0;
                                            }, Navigator.Instance.CanGoBack);

            _goForward = new ActionCommand(()=>
                                               {
                                                   Navigator.Instance.GoForward();
                                                   SelectedIndex = 0;
                                               }, Navigator.Instance.CanGoForward);

            Navigator.Instance.NavigationCallback += (e, page) =>
                                                         {
                                                             if (page.HasValue)
                                                             {
                                                                 var example =
                                                                     Module.Examples.FirstOrDefault(
                                                                         ex => ex.PageId == page.Value);

                                                                 SelectedExample = example;

                                                                 RaiseCanNavigateHomeChanged();
                                                                 RaiseCanNavigateBackForwardChanged();
                                                             }
                                                         };
        }

        #region Properties

        public IEnumerable<ExampleSearchViewModel> AllExamples
        {
            get { return Module.Examples.Select(example => new ExampleSearchViewModel { Example = example, Name = example.ExampleDisplayName}); }
        }

        public string VersionAndLicenseInfo
        {
            get { return SciChartSurface.VersionAndLicenseInfo; }
        }

        public GroupedExamplesViewModel GroupedExamples
        {
            get { return (GroupedExamplesViewModel)Module.Register[ApplicationPage.HomePageId].ViewModel; }
        }

        public Guid HomePage
        {
            get { return ApplicationPage.HomePageId; }
        }

        public int SelectedIndex
        {
            get { return _selectedIndex; }
            set { _selectedIndex = value;
                OnPropertyChanged("SelectedIndex");
            }
        }

        public bool IsHomePage
        {
            get { return _isHomePage; }
            set
            {
                _isHomePage = value;
                OnPropertyChanged("IsHomePage");
            }
        }

        public Example SelectedExample 
        { 
            get { return _selectedExample; } 
            set 
            {
                if (_selectedExample == null || !_selectedExample.Equals(value))
                {
                    _selectedExample = value;
                    OnPropertyChanged("SelectedExample");
                }
            } 
        }

        #endregion

        #region Commands 

        public ICommand GoToHomePage
        {
            get { return _goHome; }
        }

        public ICommand GoBack
        {
            get { return _goBack; }
        }

        public ICommand GoForward
        {
            get
            {
                return _goForward;
            }
        }

        #endregion

        #region Methods

        private void RaiseCanNavigateBackForwardChanged()
        {
            _goBack.RaiseCanExecuteChanged();
            _goForward.RaiseCanExecuteChanged();
        }

        private void RaiseCanNavigateHomeChanged()
        {
            _goHome.RaiseCanExecuteChanged();
            var page = Navigator.Instance.GetCurrentPage();
            IsHomePage = page != null && page.PageId == HomePage;
        }
        #endregion
    }
}

