﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Windows.Input;
using Abt.Controls.SciChart.Example.Helpers;

namespace Abt.Controls.SciChart.Example
{
    internal class Module
    {
        public static readonly List<Example> Examples = new List<Example>();

        public static readonly Dictionary<Guid, ApplicationPage> Register = new Dictionary<Guid, ApplicationPage>();
        private static readonly ActionCommand<Example> _navigateToExampleCommand;

        static Module()
        {
            _navigateToExampleCommand = new ActionCommand<Example>(example =>
            {
                if (Navigator.Instance.CanNavigateTo(example.PageId))
                {
                    Navigator.Instance.Navigate(example.PageId);
                }
            });
        }

        private static ICommand NavigateToExample
        {
            get { return _navigateToExampleCommand; }
        }

        public static void Initialize()
        {
            var exampleDefinitions = LoadExampleDefinitions()
                .ToList();

            InitializeExamplesAndPages(exampleDefinitions);

            InitializeNavigator();
        }

        private static IEnumerable<ExampleDefinition> LoadExampleDefinitions()
        {
            var loader = new ExampleLoader();

            var xmlExamples = loader.DiscoverAllXmlFiles().Values;

            var exampleDefinitions = xmlExamples
                .Select(loader.Parse);

            return exampleDefinitions;
        }

        private static void InitializeExamplesAndPages(IEnumerable<ExampleDefinition> exampleDefinitions)
        {
            ApplicationPage page;
            foreach (var definition in exampleDefinitions)
            {
                page = new ApplicationPage(definition.ViewModel, definition.View);
                Register.Add(page.PageId, page);

                var example = new Example(page.PageId, definition.CodeFiles)
                {
                    ExampleDescription = definition.Description,
                    ExampleToolTipDescription = definition.ToolTipDescription,
                    ExampleDisplayName = definition.Title,
                    ExampleHelpText = definition.HelpText,
                    ExampleImagePath = definition.ImagePath,
                    Group = definition.ChartGroup,
                    IconPath = definition.IconPath,
                    SelectCommand = NavigateToExample,
                    UsedChartTypes = definition.ChartTypes,
                    Edition = definition.Edition,
                    Features = definition.Features
                };

                Examples.Add(example);
            }

            page = new ApplicationPage("GroupedExamplesViewModel", "HomeControl.xaml", true);
            Register.Add(page.PageId, page);
        }

        private static void InitializeNavigator()
        {
            Navigator.Instance.AfterNavigation = (view, viewModel) =>
            {
                view.DataContext = viewModel;

                OnExampleEnter(view as IExampleAware, viewModel as IExampleAware);
            };

            Navigator.Instance.BeforeNavigation = (view, viewModel) => OnExampleExit(view as IExampleAware, viewModel as IExampleAware);
        }

        private static void OnExampleExit(IExampleAware view, IExampleAware viewModel)
        {
            if (view != null) view.OnExampleExit();

            if (viewModel != null) viewModel.OnExampleExit();
        }

        private static void OnExampleEnter(IExampleAware view, IExampleAware viewModel)
        {
            if (view != null) view.OnExampleEnter();

            if (viewModel != null) viewModel.OnExampleEnter();
        }
    }
}
