﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using Abt.Controls.SciChart.Example.Common;
using Abt.Controls.SciChart.Example.Data;
using Abt.Controls.SciChart.Example.MVVM;

namespace Abt.Controls.SciChart.Example.Examples.IWantTo.AnnotateAChart.OverlayTradeMarkers
{
    public class TradeOverlayExampleViewModel : BaseViewModel, IExampleAware
    {
        private IDataSeriesSet<DateTime, double> _priceData;
        private AnnotationCollection _annotations;

        public AnnotationCollection TradeAnnotations
        {
            get { return _annotations; }
            set 
            { 
                _annotations = value;
                OnPropertyChanged("TradeAnnotations");
            }
        }

        public IDataSeriesSet<DateTime, double> PriceData
        {
            get { return _priceData; }
            set
            {
                _priceData = value;
                OnPropertyChanged("PriceData");
            }
        }

        public void OnExampleExit()
        {            
        }

        /// <summary>
        /// Called by the Example App framework when the example is shown
        /// </summary>
        public void OnExampleEnter()
        {            
            // Create some data to show on the chart
            var dataset = new DataSeriesSet<DateTime, double>();
            var priceSeries = dataset.AddSeries();
            priceSeries.SeriesName = "CL FUT JUN15 2013";

            // Get some price data, trades
            List<Trade> trades;
            List<NewsEvent> newsEvents;
            var priceData = DataManager.Instance.GetRandomTrades(out trades, out newsEvents);

            // Buffer above and append all in one go to avoid multiple recalculations of series range
            priceSeries.Append(priceData.TimeData, priceData.CloseData);
            PriceData = dataset;

            // Create annotations           
            TradeAnnotations = CreateAnnotations(trades, newsEvents);
        }

        private static AnnotationCollection CreateAnnotations(IEnumerable<Trade> trades, List<NewsEvent> newsEvents)
        {
            var annotations = new AnnotationCollection();
            foreach (var trade in trades)
            {
                IAnnotation annotation = trade.BuySell == BuySell.Buy ? new BuyMarkerAnnotation() : (IAnnotation)new SellMarkerAnnotation();

                // The datacontext allows the tooltip inside the buy or sell marker to bind to elements of the Trade
                annotation.DataContext = trade;

                // X1,Y1 we set up manually
                annotation.X1 = trade.TradeDate;
                annotation.Y1 = trade.DealPrice;

                annotations.Add(annotation);
            }

            foreach(var newsEvent in newsEvents)
            {
                var annotation = new NewsBulletAnnotation();

                // The datacontext allows the tooltip to bind to news data
                annotation.DataContext = newsEvent;

                // X1 is equal to the news date
                annotation.X1 = newsEvent.EventDate;

                // Y1 is set to 0.99, which is the just inside the vertical bottom edge of the chart in relative mode
                annotation.Y1 = 0.99;

                // Finally we use CoordinateMode.RelativeY to have a fractional coordinate on Y-Axis
                // this ensures the news bullets always appear at the bottom of the chart regardless
                // of YAxis.VisibleRange
                annotation.CoordinateMode = AnnotationCoordinateMode.RelativeY;

                annotations.Add(annotation);
            }
            return annotations;
        }
    }
}
