﻿using System.ComponentModel;
using System.Linq;
using Abt.Controls.SciChart;
using ScreenshotsAndXpsExport.Annotations;

namespace ScreenshotsAndXpsExport
{
    public class ChartViewModel : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        private IDataSeriesSet _chartData;
        private ILabelFormatter _labelFormatter;

        public ChartViewModel()
        {
            var dataset = new DataSeriesSet<int, double>();
            var dataSeries = dataset.AddSeries();

            // Create the X-Axis Labels
            var xAxisLabels = new[] {"Java", "Obj-C", "C#", "Fortran", "C++"};

            // We append Y-values (double) and X-values are just indices to the x-axis (string) labels
            dataSeries.Append(Enumerable.Range(0, 5), new[] { 2.2, 5.3, 9.5, 6.7, 8.4});
            ChartData = dataset;

            // The ILabelFormatter allows us to substitute a string value for a data-value. 
            // In most cases this is used to format a numeric value, e.g. 1.23456 as "1.23", however
            // we can also use it to transform an integer value to a string (text) value
            XLabelFormatter = new CustomLabelFormatter(xAxisLabels);
        }

        public IDataSeriesSet ChartData
        {
            get { return _chartData; }
            set
            {
                _chartData = value;
                OnPropertyChanged("ChartData");
            }
        }

        public ILabelFormatter XLabelFormatter
        {
            get { return _labelFormatter; }
            set
            {
                _labelFormatter = value;
                OnPropertyChanged("XLabelFormatter");
            }
        }

        [NotifyPropertyChangedInvocator]
        protected virtual void OnPropertyChanged(string propertyName = null)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
