﻿using System;
using System.Diagnostics;
using System.Windows;
using System.Windows.Media;
using Abt.Controls.SciChart;
using Abt.Controls.SciChart.Utility;

namespace SimpleLineChart
{
    public partial class MainWindow : Window
    {
        private class OutputWindowLogger : ISciChartLoggerFacade
        {
            public void Log(string formatString, params object[] args)
            {
                Debug.WriteLine(formatString, args);
            }
        }

        public MainWindow()
        {
            // Setting a logger will log debug messages to the console, but will incur a HUGE performance hit
            // so use it wisely! 
            SciChartDebugLogger.Instance.SetLogger(new OutputWindowLogger());
            SciChartDebugLogger.Instance.WriteLine("Hellow World!");
            InitializeComponent();

            Loaded += MainWindowLoaded;
        }

        private void MainWindowLoaded(object sender, RoutedEventArgs e)
        {            
            // GrowBy expands a gap around the data when zooming to extents
            sciChartSurface.YAxis.GrowBy = new DoubleRange(0.2, 0.2);

            // VisibleRange may be set explicitly, or use AutoRange to zoom to extents
            sciChartSurface.XAxis.VisibleRange = new DoubleRange(0, 600);
            sciChartSurface.YAxis.VisibleRange = new DoubleRange(-0.6, 1.2);
                       
            // Add a data series and some data
            var dataset = new DataSeriesSet<double, double>();
            var series = dataset.AddSeries();
            series.SeriesName ="Sinewave";

            for(int i = 0; i < 1000; i++)
            {
                series.Append(i, Math.Sin(2*Math.PI*i/1000));
            }
                        
            // Note: Can also be set in Xaml, inside the <SciChartSurface.DataSet> tag
            sciChartSurface.DataSet = dataset;
        }
    }
}
