﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using Abt.Controls.SciChart;

namespace _08_Synchronize_Mouse_Events
{
    public class MultiChartMouseEventsViewModel : INotifyPropertyChanged
    {
        private bool mouseWheelEnabled;
        private bool panEnabled;
        private bool rolloverEnabled;
        private bool cursorEnabled;
        private bool zoomEnabled;
        private IRange sharedXVisibleRange;
        private readonly IDataSeriesSet _chartData0;
        private readonly IDataSeriesSet _chartData1;

        public MultiChartMouseEventsViewModel()
        {
            // Create two datasets which we will bind to
            _chartData0 = CreateDataset();
            _chartData1 = CreateDataset();

            // Set default states of modifiers
            this.MouseWheelEnabled = false;
            this.PanEnabled = true;
            this.CursorEnabled = true;

            // Set default shared XAxis VisibleRange which multiple charts will bind to
            SharedXVisibleRange = new DoubleRange(0, 1);
        }

        public IRange SharedXVisibleRange
        {
            get { return sharedXVisibleRange; }
            set
            {
                if (sharedXVisibleRange == value) return;
                sharedXVisibleRange = value;
                OnPropertyChanged("SharedXVisibleRange");
            }
        }

        public IDataSeriesSet ChartData0 { get { return _chartData0; } }
        public IDataSeriesSet ChartData1 { get { return _chartData1; } }

        public bool MouseWheelEnabled
        {
            get { return mouseWheelEnabled; }
            set
            {
                if (mouseWheelEnabled == value) return;
                mouseWheelEnabled = value;
                OnPropertyChanged("MouseWheelEnabled");
            }
        }

        public bool PanEnabled
        {
            get { return panEnabled; }
            set
            {
                if (panEnabled == value) return;
                panEnabled = value;
                OnPropertyChanged("PanEnabled");

                // Toggle Zoom off
                ZoomEnabled = !PanEnabled;
            }
        }

        public bool ZoomEnabled
        {
            get { return zoomEnabled; }
            set
            {
                if (zoomEnabled == value) return;
                zoomEnabled = value;
                OnPropertyChanged("ZoomEnabled");

                // Toggle pan off
                PanEnabled = !ZoomEnabled;
            }
        }

        public bool CursorEnabled
        {
            get { return cursorEnabled; }
            set
            {
                if (cursorEnabled == value) return;
                cursorEnabled = value;
                OnPropertyChanged("CursorEnabled");

                // Toggle RolloverEnabled off
                RolloverEnabled = !CursorEnabled;
            }
        }

        public bool RolloverEnabled
        {
            get { return rolloverEnabled; }
            set
            {
                if (rolloverEnabled == value) return;
                rolloverEnabled = value;
                OnPropertyChanged("RolloverEnabled");

                // Toggle RolloverEnabled off
                CursorEnabled = !RolloverEnabled;
            }
        }

        private IDataSeriesSet CreateDataset()
        {
            var ds = new DataSeriesSet<double, double>();
            var ds0 = ds.AddSeries();

            const int count = 1000;
            for (int i = 0; i < count; i++)
            {
                ds0.Append(i, count * Math.Sin(i * Math.PI * 0.1) / i);
            }

            return ds;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged(string propertyName)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
